==> material-ui-shell-3.3.0.tgz: package/es/containers/Page/ListPage.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import FilterDrawer from 'material-ui-shell/lib/components/FilterDrawer';
import Page from 'material-ui-shell/lib/containers/Page';
import React from 'react';
import SearchField from 'material-ui-shell/lib/components/SearchField';
import { Toolbar, IconButton } from '@mui/material';
import { FilterList } from '@mui/icons-material';
import VirtualList from 'material-ui-shell/lib/containers/VirtualList';
import { useFilter } from 'material-ui-shell/lib/providers/Filter';
export default function (props) {
  var _props$fields = props.fields,
      fields = _props$fields === void 0 ? [] : _props$fields,
      _props$list = props.list,
      source = _props$list === void 0 ? [] : _props$list,
      _props$getPageProps = props.getPageProps,
      getPageProps = _props$getPageProps === void 0 ? function () {} : _props$getPageProps,
      listProps = props.listProps,
      Row = props.Row,
      name = props.name,
      _props$trailing = props.trailing,
      trailing = _props$trailing === void 0 ? null : _props$trailing,
      _props$leading = props.leading,
      leading = _props$leading === void 0 ? null : _props$leading,
      _props$disableSearch = props.disableSearch,
      disableSearch = _props$disableSearch === void 0 ? false : _props$disableSearch,
      _props$disableFilter = props.disableFilter,
      disableFilter = _props$disableFilter === void 0 ? false : _props$disableFilter;

  var _useFilter = useFilter(),
      openFilter = _useFilter.openFilter,
      getList = _useFilter.getList,
      getFilter = _useFilter.getFilter,
      setSearch = _useFilter.setSearch;

  var _getFilter = getFilter(name),
      _getFilter$queries = _getFilter.queries,
      queries = _getFilter$queries === void 0 ? [] : _getFilter$queries,
      _getFilter$search = _getFilter.search,
      search = _getFilter$search === void 0 ? {} : _getFilter$search;

  var _search$value = search.value,
      searchValue = _search$value === void 0 ? '' : _search$value;
  var list = getList(name, source, fields);
  return /*#__PURE__*/React.createElement(Page, _extends({
    contentStyle: {
      overflow: 'hidden'
    },
    appBarContent: /*#__PURE__*/React.createElement(Toolbar, {
      disableGutters: true
    }, leading, !disableSearch && /*#__PURE__*/React.createElement(SearchField, {
      initialValue: searchValue,
      onChange: function onChange(v) {
        setSearch(name, v);
      }
    }), fields.length > 0 && !disableFilter && /*#__PURE__*/React.createElement(IconButton, {
      color: "inherit",
      onClick: function onClick() {
        return openFilter(name);
      }
    }, /*#__PURE__*/React.createElement(FilterList, {
      color: queries.length > 0 ? 'secondary' : undefined
    })), trailing)
  }, getPageProps(list)), /*#__PURE__*/React.createElement(VirtualList, {
    list: list,
    name: name,
    listProps: listProps,
    Row: Row
  }), fields.length > 0 && /*#__PURE__*/React.createElement(FilterDrawer, {
    fields: fields,
    name: name
  }));
}

==> material-ui-shell-3.3.8.tgz: package/es/containers/Page/ListPage.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import FilterDrawer from '../../components/FilterDrawer';
import Page from '../../containers/Page';
import React from 'react';
import SearchField from '../../components/SearchField';
import { Toolbar, IconButton } from '@mui/material';
import { FilterList } from '@mui/icons-material';
import VirtualList from '../../containers/VirtualList';
import { useFilter } from '../../providers/Filter';
export default function (props) {
  var _props$fields = props.fields,
      fields = _props$fields === void 0 ? [] : _props$fields,
      _props$list = props.list,
      source = _props$list === void 0 ? [] : _props$list,
      _props$getPageProps = props.getPageProps,
      getPageProps = _props$getPageProps === void 0 ? function () {} : _props$getPageProps,
      listProps = props.listProps,
      Row = props.Row,
      name = props.name,
      _props$trailing = props.trailing,
      trailing = _props$trailing === void 0 ? null : _props$trailing,
      _props$leading = props.leading,
      leading = _props$leading === void 0 ? null : _props$leading,
      _props$disableSearch = props.disableSearch,
      disableSearch = _props$disableSearch === void 0 ? false : _props$disableSearch,
      _props$disableFilter = props.disableFilter,
      disableFilter = _props$disableFilter === void 0 ? false : _props$disableFilter;

  var _useFilter = useFilter(),
      openFilter = _useFilter.openFilter,
      getList = _useFilter.getList,
      getFilter = _useFilter.getFilter,
      setSearch = _useFilter.setSearch;

  var _getFilter = getFilter(name),
      _getFilter$queries = _getFilter.queries,
      queries = _getFilter$queries === void 0 ? [] : _getFilter$queries,
      _getFilter$search = _getFilter.search,
      search = _getFilter$search === void 0 ? {} : _getFilter$search;

  var _search$value = search.value,
      searchValue = _search$value === void 0 ? '' : _search$value;
  var list = getList(name, source, fields);
  return /*#__PURE__*/React.createElement(Page, _extends({
    contentStyle: {
      overflow: 'hidden'
    },
    appBarContent: /*#__PURE__*/React.createElement(Toolbar, {
      disableGutters: true
    }, leading, !disableSearch && /*#__PURE__*/React.createElement(SearchField, {
      initialValue: searchValue,
      onChange: function onChange(v) {
        setSearch(name, v);
      }
    }), fields.length > 0 && !disableFilter && /*#__PURE__*/React.createElement(IconButton, {
      color: "inherit",
      onClick: function onClick() {
        return openFilter(name);
      }
    }, /*#__PURE__*/React.createElement(FilterList, {
      color: queries.length > 0 ? 'secondary' : undefined
    })), trailing)
  }, getPageProps(list)), /*#__PURE__*/React.createElement(VirtualList, {
    list: list,
    name: name,
    listProps: listProps,
    Row: Row
  }), fields.length > 0 && /*#__PURE__*/React.createElement(FilterDrawer, {
    fields: fields,
    name: name
  }));
}
